/*
  gmap.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "centermarker.h"
#include "layeredbase.h"
#include "mainwindow.h"
#include <qpixmap.h>

CenterMarker::CenterMarker( LayeredBase *parent, const char *name) :
	LayeredWidget(parent, name)
{
	marker_on = ((MainWindow *)parentWidget())->getNumConfig("CenterMarker", false);
}

bool CenterMarker::paintEvent( QPixmap &scr )
{
	QPainter p(&scr);

	if(!marker_on)
		return false;

	int x = parentWidget()->width()/2;
	int y = parentWidget()->height()/2;

	p.setPen(Qt::black);
	p.drawLine(x-20, y, x+20, y);
	p.drawLine(x, y-20, x, y+20);
	return true;
}

bool CenterMarker::keyPressEvent(QKeyEvent *e)
{
	if(e->key() == Key_Period && !(e->state() & ShiftButton)){
		marker_on = !marker_on;
		((MainWindow *)parentWidget())->setConfig("CenterMarker", marker_on);
		repaint();
		return true;
	}
	return false;
}
