/*
  freehanddialog.cpp
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "qgmap.h"
#include "freehanddialog.h"
#include "qstring.h"
#include "qlabel.h"
#include "qvbox.h"
#include "qhbox.h"
#include "qspinbox.h"
#include "qhgroupbox.h"
#include "qhbuttongroup.h"
#include "qradiobutton.h"
#include "qpushbutton.h"
#include "qsizepolicy.h"

#include "pos.h"

#define DIALOG_WIDTH  400
#ifdef QWS
#define DIALOG_HEIGHT (FRAME_HEIGHT*2+4)
#else
#define DIALOG_HEIGHT (FRAME_HEIGHT*2+40)
#endif

#define FRAME_HEIGHT 58

FreehandDialog::FreehandDialog( QWidget* parent, const char* name,
								bool modal UNUSED, WFlags fl)
	: QDialog( parent, name, TRUE, fl )
{
    resize( QSize(DIALOG_WIDTH, DIALOG_HEIGHT).expandedTo(minimumSizeHint()) );

	setCaption(QString::fromUtf8("保存範囲・形式指定"));

	setFont(QFont("lcfont", 16));

	zoomGroup = new QHGroupBox("Zoom Level", this);
	zoomGroup->setGeometry(4, 0, DIALOG_WIDTH-4*2, FRAME_HEIGHT);
	zoomLabel = new QLabel(QString::fromUtf8("保存レベル"), zoomGroup);
	minZoom = new QSpinBox(MIN_ZOOM, MAX_ZOOM, 1, zoomGroup);
	minZoom->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
	fromtoLabel = new QLabel(QString::fromUtf8("-"), zoomGroup);
	fromtoLabel->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
	maxZoom = new QSpinBox(MIN_ZOOM, MAX_ZOOM, 1, zoomGroup);
	maxZoom->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));

	connect(minZoom, SIGNAL(valueChanged(int)),
			this, SLOT(change_min(int)));
	connect(maxZoom, SIGNAL(valueChanged(int)),
			this, SLOT(change_max(int)));

	formatGroup = new QHButtonGroup("Format", this);
	formatGroup->setGeometry(4, FRAME_HEIGHT, DIALOG_WIDTH-4*2, FRAME_HEIGHT);
	formatShell = new QRadioButton(QString::fromUtf8("Shellスクリプト形式"), formatGroup);
	formatPerl = new QRadioButton(QString::fromUtf8("Perl形式"), formatGroup);
	formatPerl->setChecked(true);

#ifndef QWS
	hbox = new QHBox(this);
	hbox->setGeometry(4, FRAME_HEIGHT*2, DIALOG_WIDTH-4*2, 40);
	cancel = new QPushButton("Cancel", hbox);
	ok = new QPushButton("OK", hbox);
	ok->setDefault(true);

	connect(cancel, SIGNAL(clicked()),
			this, SLOT(press_cancel()));
	connect(ok, SIGNAL(clicked()),
			this, SLOT(press_ok()));
#endif
}

FreehandDialog::~FreehandDialog()
{
}

void FreehandDialog::press_ok()
{
	accept();
}

void FreehandDialog::press_cancel()
{
	reject();
}

void FreehandDialog::change_min(int value)
{
	int max = maxZoom->text().toInt();
	if(max < value){
		maxZoom->setValue(value);
	}
}

void FreehandDialog::change_max(int value)
{
	int min = minZoom->text().toInt();
	if(min > value){
		minZoom->setValue(value);
	}
}

void FreehandDialog::setNowZoom(int zoom)
{
	zoomLabel->setText(QString::fromUtf8("保存レベル (現在=%1)").arg(zoom));
	minZoom->setValue(zoom);
	maxZoom->setValue(zoom);
}

int FreehandDialog::getMinZoom()
{
	return minZoom->text().toInt();
}

int FreehandDialog::getMaxZoom()
{
	return maxZoom->text().toInt();
}

int FreehandDialog::getFormat()
{
	return formatShell->isChecked()?ShellScript:PerlScript;
}
