/*
  freehandregion.h
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __FREEHANDREGION_H__
#define __FREEHANDREGION_H__

#include <qwidget.h>
#include <qpixmap.h>
#include <qvector.h>
#include <qpointarray.h>
#include "layeredwidget.h"
#include "pos.h"

class QString;
class QPaintEvent;
class QImage;
class RegionMap;

class FreehandRegion : public LayeredWidget
{
	Q_OBJECT
  public:
	FreehandRegion( LayeredBase *parent =0, const char *name = 0);
	bool paintEvent(QPixmap &scr);
	bool mousePressEvent(QMouseEvent *e);
	bool mouseReleaseEvent(QMouseEvent *e);
	bool mouseMoveEvent(QMouseEvent *e);
	bool keyPressEvent ( QKeyEvent * e );
	void showEvent();

  private:
	QPixmap canvas;
	QPixmap saved_screen;
	QPointArray points;
	QVector<QPointArray> parray;

	bool is_button;
	enum {NONE, FETCH, DRAW} mode;

	QPoint old;
	Pos  center;

	void addPoint(const QPoint &point);
	void clearParray();
	void popParray();
	void redrawCanvas();
	void fetchScreen(QPixmap const &scr);
	void freeAll();

	void hideWidget();
	void showWidget();

	void mode_on();
	void mode_off();
	int save_region();
	RegionMap *create_normalized_mask();
	QString create_command(RegionMap *map, int zoom, int format);

  public slots:
	void setPosition( Pos &pos );
};

#endif // __FREEHANDREGION_H__
