/*
  scale.h
  Copyright (C) 2008 Tomohiro Masubuchi <bucchi@e-ml.jp>

  This file is part of qgmap.

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; If not, see <http://www.gnu.org/licenses/>.
*/

#include "qgmap.h"
#include "scale.h"

#include <qwidget.h>
#include <qpixmap.h>
#include <qpainter.h>
#include "pos.h"

Scale::Scale( LayeredBase *parent, const char *name) :
	LayeredWidget(parent, name)
{
	scale_size = 0;
	scale_mul = 0;

	timer_id = -1;
}

bool Scale::paintEvent( QPixmap &scr )
{
	QPainter p(&scr);

	int xoff = 10, yoff = scr.height() - 24;

	p.setPen(Qt::white);
	p.drawRect(xoff, yoff+4, 4,14);
	p.drawRect(xoff+scale_size, yoff+4, 4,14);
	p.drawRect(xoff, yoff+4+10, scale_size+4,4);

	p.setPen(Qt::black);
	p.drawRect(xoff+1, yoff+4+1, 2,10);
	p.drawRect(xoff+1+scale_size, yoff+4+1, 2,10);
	p.drawRect(xoff+1, yoff+4+11, scale_size+2,2);

	QFont font = QFont::defaultFont();
	font.setPixelSize(SCALE_FONT_SIZE);
	p.setFont(font);
	QString str;
	if(scale_mul>1000)
		str.sprintf("%dkm",scale_mul/1000);
	else
		str.sprintf("%dm",scale_mul);

	p.drawText(xoff+10, yoff+10, str);

	return true;
}

void Scale::setPosition(Pos &pos)
{
	if(timer_id > 0){
		killTimer(timer_id);
		timer_id=-1;
	}

	center = pos;

	timer_id = startTimer(200);
}

void Scale::timerEvent( QTimerEvent *e )
{
	int id;

	id = e->timerId();
	if(id == timer_id){
		killTimer(id);
		timer_id=-1;
	}

	scale_size = center.getScaleSize(SCALE_MAX_SIZE, &scale_mul);
	repaint();
}
